.. py:function:: sf_airy_Bi_deriv_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Bi_deriv_e`
    c code signature: int gsl_sf_airy_Bi_deriv_e(const double x,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_Ai_deriv_scaled(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Ai_deriv_scaled`
    c code signature: double gsl_sf_airy_Ai_deriv_scaled(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_zero_Ai_deriv_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_zero_Ai_deriv_e`
    c code signature: int gsl_sf_airy_zero_Ai_deriv_e( unsigned int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rl__Ord`
    
    :param unsigned int s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_airy_Bi_scaled_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Bi_scaled_e`
    c code signature: int gsl_sf_airy_Bi_scaled_e(const double x,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_Bi(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Bi`
    c code signature: double gsl_sf_airy_Bi(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_zero_Bi_deriv(s [, ret])

    Wrapper for :c:func:`gsl_sf_airy_zero_Bi_deriv`
    c code signature: double gsl_sf_airy_zero_Bi_deriv( unsigned int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rd__O`
    
    :param unsigned int s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_Bi_deriv(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Bi_deriv`
    c code signature: double gsl_sf_airy_Bi_deriv(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_zero_Bi_deriv_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_zero_Bi_deriv_e`
    c code signature: int gsl_sf_airy_zero_Bi_deriv_e( unsigned int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rl__Ord`
    
    :param unsigned int s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_airy_Bi_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Bi_e`
    c code signature: int gsl_sf_airy_Bi_e(const double x,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_Ai_deriv_scaled_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Ai_deriv_scaled_e`
    c code signature: int gsl_sf_airy_Ai_deriv_scaled_e(const double x,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_Ai_scaled(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Ai_scaled`
    c code signature: double gsl_sf_airy_Ai_scaled(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_Bi_scaled(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Bi_scaled`
    c code signature: double gsl_sf_airy_Bi_scaled(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_Ai_scaled_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Ai_scaled_e`
    c code signature: int gsl_sf_airy_Ai_scaled_e(const double x,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_Ai_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Ai_e`
    c code signature: int gsl_sf_airy_Ai_e(const double x, const gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_Ai_deriv_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Ai_deriv_e`
    c code signature: int gsl_sf_airy_Ai_deriv_e(const double x,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_zero_Ai_deriv(s [, ret])

    Wrapper for :c:func:`gsl_sf_airy_zero_Ai_deriv`
    c code signature: double gsl_sf_airy_zero_Ai_deriv( unsigned int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rd__O`
    
    :param unsigned int s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_zero_Ai_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_zero_Ai_e`
    c code signature: int gsl_sf_airy_zero_Ai_e( unsigned int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rl__Ord`
    
    :param unsigned int s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_airy_Bi_deriv_scaled_e(x, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_Bi_deriv_scaled_e`
    c code signature: int gsl_sf_airy_Bi_deriv_scaled_e(const double x,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_airy_zero_Bi(s [, ret])

    Wrapper for :c:func:`gsl_sf_airy_zero_Bi`
    c code signature: double gsl_sf_airy_zero_Bi( unsigned int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rd__O`
    
    :param unsigned int s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_Bi_deriv_scaled(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Bi_deriv_scaled`
    c code signature: double gsl_sf_airy_Bi_deriv_scaled(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_zero_Ai(s [, ret])

    Wrapper for :c:func:`gsl_sf_airy_zero_Ai`
    c code signature: double gsl_sf_airy_zero_Ai( unsigned int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rd__O`
    
    :param unsigned int s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_zero_Bi_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_airy_zero_Bi_e`
    c code signature: int gsl_sf_airy_zero_Bi_e( unsigned int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rl__Ord`
    
    :param unsigned int s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_airy_Ai(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Ai`
    c code signature: double gsl_sf_airy_Ai(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_airy_Ai_deriv(x, mode [, ret])

    Wrapper for :c:func:`gsl_sf_airy_Ai_deriv`
    c code signature: double gsl_sf_airy_Ai_deriv(const double x,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double x: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

